@@ -1,7 +1,17 @@
+#undef OPENSSL
+
 #undef GNU_MP
 
+#undef MPI
+
+#undef TOMCRYPT
+
+#undef TOMMATH
+
 #undef CRYPTOLIB
 
+#undef OPENSSL_ENGINE
+
 #undef ENABLE_YP
 
 #undef HIGHFIRST
